@@ -6,6 +6,7 @@ memes = [
     Meme("petpet", petpet, ("摸", "摸摸", "摸头", "rua"), r"摸摸?头?|rua"),
     Meme("kiss", kiss, ("亲", "亲亲"), r"亲亲?"),
     Meme("rub", rub, ("贴", "贴贴", "蹭", "蹭蹭"), r"贴贴?|蹭蹭?"),
+    Meme("capoo_rub", capoo_rub, ("咖波蹭",)),
     Meme("play", play, ("顶", "玩")),
     Meme("pat", pat, ("拍",)),
     Meme("rip", rip, ("撕",)),
@@ -25,7 +26,9 @@ memes = [
     Meme("play_game", play_game, ("玩游戏",), r"来?玩游戏"),
     Meme("worship", worship, ("膜", "膜拜"), r"膜拜?"),
     Meme("eat", eat, ("吃",)),
+    Meme("klee_eat", klee_eat, ("可莉吃",)),
     Meme("bite", bite, ("啃",)),
+    Meme("hutao_bite", hutao_bite, ("胡桃啃",)),
     Meme("police", police, ("出警",)),
     Meme("police1", police1, ("警察",)),
     Meme("ask", ask, ("问问",), r"去?问问"),
@@ -97,6 +100,11 @@ memes = [
     Meme("wave", wave, ("波纹",)),
     Meme("rise_dead", rise_dead, ("诈尸", "秽土转生")),
     Meme("kirby_hammer", kirby_hammer, ("卡比锤", "卡比重锤")),
+    Meme("wooden_fish", wooden_fish, ("木鱼",)),
+    Meme("karyl_point", karyl_point, ("凯露指",)),
+    Meme("kick_ball", kick_ball, ("踢球",)),
+    Meme("smash", smash, ("砸",)),
+    Meme("bocchi_draft", bocchi_draft, ("波奇手稿",)),
 ]
 
 memes = [meme for meme in memes if meme.name not in petpet_config.petpet_disabled_list]
